@@ -12,7 +12,7 @@ use Tags::HTML::Messages;
 
 Readonly::Array our @FORM_METHODS => qw(post get);
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Constructor.
 sub new {
@@ -506,19 +506,30 @@ Returns undef.
  use CSS::Struct::Output::Indent;
  use Plack::App::Tags::HTML;
  use Plack::Runner;
+ use Tags::HTML::Login::Access;
  use Tags::Output::Indent;
  use Unicode::UTF8 qw(decode_utf8);
  
+ my $css = CSS::Struct::Output::Indent->new;
+ my $tags = Tags::Output::Indent->new(
+         'xml' => 1,
+         'preserved' => ['style'],
+ );
+ my $login = Tags::HTML::Login::Access->new(
+         'css' => $css,
+         'tags' => $tags,
+         'register_url' => '/register',
+ );
+ $login->process_css;
  my $app = Plack::App::Tags::HTML->new(
-         'component' => 'Tags::HTML::Login::Access',
-         'constructor_args' => {
-                 'register_url' => '/register',
-         },
-         'css' => CSS::Struct::Output::Indent->new,
-         'tags' => Tags::Output::Indent->new(
-                 'xml' => 1,
-                 'preserved' => ['style'],
-         ),
+         'component' => 'Tags::HTML::Container',
+         'data' => [sub {
+                 my $self = shift;
+                 $login->process;
+                 return;
+         }],
+         'css' => $css,
+         'tags' => $tags,
          'title' => 'Login and password',
  )->to_app;
  Plack::Runner->new->run($app);
@@ -574,6 +585,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
